@@ -453,11 +453,14 @@ class _PostPhaseCommands(CompositeTask):
 			if msg:
 				self.scheduler.output(msg, log_path=self.settings.get("PORTAGE_LOG_FILE"))
 
-			# This operates on REQUIRES metadata generated by the above function call.
-			future = self._soname_deps_qa()
-			# If an unexpected exception occurs, then this will raise it.
-			future.add_done_callback(lambda future: future.result())
-			self._start_task(AsyncTaskFuture(future=future), self._default_final_exit)
+			if 'qa-unresolved-soname-deps' in self.settings.features:
+				# This operates on REQUIRES metadata generated by the above function call.
+				future = self._soname_deps_qa()
+				# If an unexpected exception occurs, then this will raise it.
+				future.add_done_callback(lambda future: future.result())
+				self._start_task(AsyncTaskFuture(future=future), self._default_final_exit)
+			else:
+				self._default_final_exit(task)
 		else:
 			self._default_final_exit(task)
 
